@@ -6,15 +6,13 @@ These classes were designed as part of an object-oriented interface for
 the tools in the PSF subpackage.
 """
 
-from __future__ import (absolute_import, division, print_function,
-                        unicode_literals)
 import abc
 
-import six
 import numpy as np
 from astropy.stats import (SigmaClip, biweight_location, biweight_scale,
                            mad_std)
-from astropy.utils.misc import InheritDocstrings
+
+from ..utils.misc import _ABCMetaAndInheritDocstrings
 
 
 __all__ = ['BackgroundBase', 'BackgroundRMSBase', 'MeanBackground',
@@ -57,12 +55,7 @@ def _masked_median(data, axis=None):
     return _median
 
 
-class _ABCMetaAndInheritDocstrings(InheritDocstrings, abc.ABCMeta):
-    pass
-
-
-@six.add_metaclass(_ABCMetaAndInheritDocstrings)
-class BackgroundBase(object):
+class BackgroundBase(metaclass=_ABCMetaAndInheritDocstrings):
     """
     Base class for classes that estimate scalar background values.
 
@@ -102,9 +95,10 @@ class BackgroundBase(object):
             `~numpy.ma.MaskedArray` will be returned.
         """
 
+        raise NotImplementedError('Needs to be implemented in a subclass.')
 
-@six.add_metaclass(_ABCMetaAndInheritDocstrings)
-class BackgroundRMSBase(object):
+
+class BackgroundRMSBase(metaclass=_ABCMetaAndInheritDocstrings):
     """
     Base class for classes that estimate scalar background RMS values.
 
@@ -144,6 +138,8 @@ class BackgroundRMSBase(object):
             `~numpy.ma.MaskedArray` will be returned.
         """
 
+        raise NotImplementedError('Needs to be implemented in a subclass.')
+
 
 class MeanBackground(BackgroundBase):
     """
@@ -273,7 +269,7 @@ class ModeEstimatorBackground(BackgroundBase):
     """
 
     def __init__(self, median_factor=3., mean_factor=2., **kwargs):
-        super(ModeEstimatorBackground, self).__init__(**kwargs)
+        super().__init__(**kwargs)
         self.median_factor = median_factor
         self.mean_factor = mean_factor
 
@@ -327,7 +323,7 @@ class MMMBackground(ModeEstimatorBackground):
     def __init__(self, **kwargs):
         kwargs['median_factor'] = 3.
         kwargs['mean_factor'] = 2.
-        super(MMMBackground, self).__init__(**kwargs)
+        super().__init__(**kwargs)
 
 
 class SExtractorBackground(BackgroundBase):
@@ -440,7 +436,7 @@ class BiweightLocationBackground(BackgroundBase):
     """
 
     def __init__(self, c=6, M=None, **kwargs):
-        super(BiweightLocationBackground, self).__init__(**kwargs)
+        super().__init__(**kwargs)
         self.c = c
         self.M = M
 
@@ -477,14 +473,14 @@ class StdBackgroundRMS(BackgroundRMSBase):
 
     >>> bkgrms_value = bkgrms.calc_background_rms(data)
     >>> print(bkgrms_value)    # doctest: +FLOAT_CMP
-    28.866070047722118
+    28.86607004772212
 
     Alternatively, the background RMS value can be calculated by calling
     the class instance as a function, e.g.:
 
     >>> bkgrms_value = bkgrms(data)
     >>> print(bkgrms_value)    # doctest: +FLOAT_CMP
-    28.866070047722118
+    28.86607004772212
     """
 
     def calc_background_rms(self, data, axis=None):
@@ -531,14 +527,14 @@ class MADStdBackgroundRMS(BackgroundRMSBase):
 
     >>> bkgrms_value = bkgrms.calc_background_rms(data)
     >>> print(bkgrms_value)    # doctest: +FLOAT_CMP
-    37.065055462640053
+    37.06505546264005
 
     Alternatively, the background RMS value can be calculated by calling
     the class instance as a function, e.g.:
 
     >>> bkgrms_value = bkgrms(data)
     >>> print(bkgrms_value)    # doctest: +FLOAT_CMP
-    37.065055462640053
+    37.06505546264005
     """
 
     def calc_background_rms(self, data, axis=None):
@@ -580,18 +576,18 @@ class BiweightScaleBackgroundRMS(BackgroundRMSBase):
 
     >>> bkgrms_value = bkgrms.calc_background_rms(data)
     >>> print(bkgrms_value)    # doctest: +FLOAT_CMP
-    30.094338485893392
+    30.09433848589339
 
     Alternatively, the background RMS value can be calculated by calling
     the class instance as a function, e.g.:
 
     >>> bkgrms_value = bkgrms(data)
     >>> print(bkgrms_value)    # doctest: +FLOAT_CMP
-    30.094338485893392
+    30.09433848589339
     """
 
     def __init__(self, c=9.0, M=None, **kwargs):
-        super(BiweightScaleBackgroundRMS, self).__init__(**kwargs)
+        super().__init__(**kwargs)
         self.c = c
         self.M = M
 
