@@ -4,6 +4,8 @@ This subpackage contains modules and packages for point spread function
 photometry.
 """
 
+from .epsf import *          # noqa
+from .epsf_stars import *    # noqa
 from .funcs import *         # noqa
 from .groupstars import *    # noqa
 from .matching import *      # noqa
