@@ -1,6 +1,5 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
-from __future__ import (absolute_import, division, print_function,
-                        unicode_literals)
+
 import itertools
 
 import numpy as np
@@ -14,8 +13,8 @@ import astropy.units as u
 from astropy.utils.misc import isiterable
 import astropy.wcs as WCS
 
-from ..properties import (SourceProperties, source_properties,
-                          SourceCatalog, properties_table)
+from ..properties import (SegmentationImage, SourceProperties,
+                          source_properties, SourceCatalog, properties_table)
 
 try:
     import scipy    # noqa
@@ -47,7 +46,7 @@ BACKGRD_VALS = [None, 0., 1., 3.5]
 
 @pytest.mark.skipif('not HAS_SKIMAGE')
 @pytest.mark.skipif('not HAS_SCIPY')
-class TestSourceProperties(object):
+class TestSourceProperties:
     def test_segment_shape(self):
         with pytest.raises(ValueError):
             SourceProperties(IMAGE, np.zeros((2, 2)), label=1)
@@ -81,6 +80,10 @@ class TestSourceProperties(object):
     def test_nowcs(self):
         props = SourceProperties(IMAGE, SEGM, wcs=None, label=1)
         assert props.sky_centroid_icrs is None
+        assert props.sky_bbox_ll is None
+        assert props.sky_bbox_ul is None
+        assert props.sky_bbox_lr is None
+        assert props.sky_bbox_ur is None
 
     def test_to_table(self):
         props = SourceProperties(IMAGE, SEGM, label=1)
@@ -96,7 +99,7 @@ class TestSourceProperties(object):
 
 @pytest.mark.skipif('not HAS_SKIMAGE')
 @pytest.mark.skipif('not HAS_SCIPY')
-class TestSourcePropertiesFunctionInputs(object):
+class TestSourcePropertiesFunctionInputs:
     def test_segment_shape(self):
         wrong_shape = np.zeros((2, 2))
         with pytest.raises(ValueError):
@@ -128,7 +131,7 @@ class TestSourcePropertiesFunctionInputs(object):
 
 @pytest.mark.skipif('not HAS_SKIMAGE')
 @pytest.mark.skipif('not HAS_SCIPY')
-class TestSourcePropertiesFunction(object):
+class TestSourcePropertiesFunction:
     def test_properties(self):
         props = source_properties(IMAGE, SEGM)
         assert props[0].id == 1
@@ -175,13 +178,19 @@ class TestSourcePropertiesFunction(object):
         for shape in shapes:
             assert shape == (4, 4)
 
-    def test_properties_background_notNone(self):
+    def test_properties_background_notnone(self):
         value = 1.
         props = source_properties(IMAGE, SEGM, background=value)
         assert props[0].background_mean == value
         assert_allclose(props[0].background_at_centroid, value)
 
-    def test_properties_error_background_None(self):
+    def test_properties_background_units(self):
+        value = 1. * u.uJy
+        props = source_properties(IMAGE, SEGM, background=value)
+        assert props[0].background_mean == value
+        assert_allclose(props[0].background_at_centroid, value)
+
+    def test_properties_error_background_none(self):
         props = source_properties(IMAGE, SEGM)
         assert props[0].background_cutout_ma is None
         assert props[0].error_cutout_ma is None
@@ -237,6 +246,14 @@ class TestSourcePropertiesFunction(object):
         for prop in proplist:
             assert np.isnan(getattr(props[0], prop))
 
+    def test_scalar_error(self):
+        error_value = 2.5
+        error = np.ones_like(IMAGE) * error_value
+        props = source_properties(IMAGE, SEGM, error=error_value)
+        props2 = source_properties(IMAGE, SEGM, error)
+        assert_quantity_allclose(props.source_sum, props2.source_sum)
+        assert_quantity_allclose(props.source_sum_err, props2.source_sum_err)
+
     def test_mask(self):
         data = np.zeros((3, 3))
         data[0, 1] = 1.
@@ -250,6 +267,14 @@ class TestSourcePropertiesFunction(object):
         assert_allclose(props[0].source_sum, 1)
         assert_allclose(props[0].area.value, 1)
 
+    def test_mask_nomask(self):
+        props = source_properties(IMAGE, SEGM, mask=np.ma.nomask)
+        mask = np.zeros(IMAGE.shape).astype(bool)
+        props2 = source_properties(IMAGE, SEGM, mask=mask)
+        assert_allclose(props.xcentroid.value, props2.xcentroid.value)
+        assert_allclose(props.ycentroid.value, props2.ycentroid.value)
+        assert_quantity_allclose(props.source_sum, props2.source_sum)
+
     def test_single_pixel_segment(self):
         segm = np.zeros_like(SEGM)
         segm[50, 50] = 1
@@ -290,10 +315,22 @@ class TestSourcePropertiesFunction(object):
         for key in keys:
             assert p1[key] != p2[key]
 
+    def test_data_nan(self):
+        """Test case when data contains NaNs within a segment."""
+
+        data = np.ones((20, 20))
+        data[2, 2] = np.nan
+        segm = np.zeros((20, 20)).astype(int)
+        segm[1:5, 1:5] = 1
+        segm[7:15, 7:15] = 2
+        segm = SegmentationImage(segm)
+        props = source_properties(data, segm)
+        assert_quantity_allclose(props.minval_xpos, [1, 7]*u.pix)
+
 
 @pytest.mark.skipif('not HAS_SKIMAGE')
 @pytest.mark.skipif('not HAS_SCIPY')
-class TestSourceCatalog(object):
+class TestSourceCatalog:
     def test_basic(self):
         segm = np.zeros(IMAGE.shape)
         x = y = np.arange(0, 100, 10)
@@ -376,7 +413,7 @@ class TestSourceCatalog(object):
 
 @pytest.mark.skipif('not HAS_SKIMAGE')
 @pytest.mark.skipif('not HAS_SCIPY')
-class TestPropertiesTable(object):
+class TestPropertiesTable:
     def test_properties_table(self):
         props = source_properties(IMAGE, SEGM)
         t = properties_table(props)
