@@ -1,6 +1,4 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
-from __future__ import (absolute_import, division, print_function,
-                        unicode_literals)
 
 import numpy as np
 from astropy import units as u
@@ -71,7 +69,7 @@ def assert_angle_or_pixel(name, q):
     """
 
     if isinstance(q, u.Quantity):
-        if q.unit.physical_type == 'angle' or q.unit is u.pixel:
+        if q.unit.physical_type == 'angle' or q.unit == u.pixel:
             pass
         else:
             raise ValueError("{0} should have angular or pixel "
